# remirepo spec file for php-pecl-seaslog
#
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-seaslog
%else
%global _root_libdir %{_libdir}
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global proj_name  SeasLog
%global pecl_name  seaslog
%global with_tests 0%{!?_without_tests:1}
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif

Summary:        An effective, fast, stable log extension for PHP
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
Version:        2.1.0
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP
URL:            https://pecl.php.net/package/%{proj_name}
Source0:        https://pecl.php.net/get/%{proj_name}-%{version}.tgz

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
An effective, fast, stable log extension for PHP.
- In the PHP project, for convenient record log.
- The default log directory and module configuration.
- Specify the log directory and get the current configuration.
- Analysis of early warning framework preliminary.
- Buffer debug efficient log buffer, convenient.
- With PSR-3 Logger interface.
- Error and exception automatic logging.
- Support appender with File,TCP,UDP.
- Send to Rsyslog(TCP/UDP) with RFC5424.
- Support RequestId differentiated requests.
- Support for log template customizations.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{proj_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
#sed -e 's/ifndef ulong/if 0/' -i include/php7_wrapper.h

: Sanity check, really often broken
extver=$(sed -n '/#define SEASLOG_VERSION /{s/.* "//;s/".*$//;p}' include/SeasLog.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;seaslog.default_basepath = '/var/log/www'
;seaslog.default_logger = 'default'
;seaslog.default_datetime_format = 'Y-m-d H:i:s'
;seaslog.default_template = '%%T | %%L | %%P | %%Q | %%t | %%M'
;seaslog.disting_folder = 1
;seaslog.disting_type = 0
;seaslog.disting_by_hour = 0
;seaslog.use_buffer = 0
;seaslog.buffer_size = 0
;seaslog.buffer_disabled_in_cli => 0
;seaslog.trace_notice = 0
;seaslog.trace_warning = 0
;seaslog.trace_error = 1
;seaslog.trace_exception = 0
;seaslog.level = 0
;seaslog.recall_depth = 0
;seaslog.appender = 1
;seaslog.appender_retry = 0
;seaslog.remote_host = '127.0.0.1'
;seaslog.remote_port = 514
;seaslog.remote_timeout => 1 => 1
;seaslog.trim_wrap = 0
;seaslog.throw_exception = 1
;seaslog.ignore_warning = 1
;seaslog.trace_performance = 0
;seaslog.trace_performance_sample_rate = 10
;seaslog.trace_performance_start_depth = 1
;seaslog.trace_performance_max_depth = 5
;seaslog.trace_performance_max_functions_per_depth = 5
;seaslog.trace_performance_min_wall_time = 1000
;seaslog.trace_performance_min_function_wall_time = 10
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-seaslog \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-seaslog \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# No useful test in tests directory

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=json.so \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i %{pecl_name}

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=json.so \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i %{pecl_name}
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%{?_licensedir:%license NTS/LICENSE}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Aug 19 2020 Remi Collet <remi@remirepo.net> - 2.1.0-2
- F33 build

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 2.1.0-1
- update to 2.1.0
- open https://github.com/SeasX/SeasLog/issues/286
  broken build on 32-bit

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.2-3
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.2-2
- rebuild for 7.4.0beta1

* Thu Jun  6 2019 Remi Collet <remi@remirepo.net> - 2.0.2-2
- add upstream patch for 7.4

* Tue Feb 12 2019 Remi Collet <remi@remirepo.net> - 2.0.2-1
- update to 2.0.2
- add dependency on %{?scl_prefix}php-json
- add new runtime option in provided configuration

* Tue Dec 18 2018 Remi Collet <remi@remirepo.net> - 1.9.1-1
- update to 1.9.1

* Mon Nov 26 2018 Remi Collet <remi@remirepo.net> - 1.9.0-1
- update to 1.9.0

* Sat Sep  8 2018 Remi Collet <remi@remirepo.net> - 1.8.6-1
- update to 1.8.6

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.8.4-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.8.4-2
- rebuild for 7.3.0alpha4 new ABI

* Fri Mar 23 2018 Remi Collet <remi@remirepo.net> - 1.8.4-1
- update to 1.8.4
- add comments for new options in provided configuration

* Tue Sep 19 2017 Remi Collet <remi@remirepo.net> - 1.7.6-1
- Update to 1.7.6

* Tue Sep 19 2017 Remi Collet <remi@remirepo.net> - 1.7.5-1
- Update to 1.7.5
- Update license from Apache License 2.0 to PHP License 3.01
- add upstream patch to fix various segfaults
  https://github.com/Neeke/SeasLog/issues/152

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.6.9-2
- rebuild for PHP 7.2.0beta1 new API

* Mon Jan 23 2017 Remi Collet <remi@fedoraproject.org> - 1.6.9-1
- Update to 1.6.9

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.6.8-2
- rebuild with PHP 7.1.0 GA

* Mon Oct 17 2016 Remi Collet <remi@fedoraproject.org> - 1.6.8-1
- Update to 1.6.8

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.6.2-2
- rebuild for PHP 7.1 new API version

* Fri Jul 08 2016 Remi Collet <remi@fedoraproject.org> - 1.6.2-1
- Update to 1.6.2

* Tue Jul 05 2016 Remi Collet <remi@fedoraproject.org> - 1.6.0-1
- Update to 1.6.0
- update provided configuration for new options

* Thu May 19 2016 Remi Collet <remi@fedoraproject.org> - 1.5.6-1
- Update to 1.5.6

* Thu Apr 07 2016 Remi Collet <remi@fedoraproject.org> - 1.5.3-1
- Update to 1.5.3

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 1.5.0-2
- adapt for F24

* Sun Dec 06 2015 Remi Collet <remi@fedoraproject.org> - 1.5.0-1
- Update to 1.5.0

* Tue Nov 10 2015 Remi Collet <remi@fedoraproject.org> - 1.4.8-1
- Update to 1.4.8 (stable)

* Fri Oct 23 2015 Remi Collet <remi@fedoraproject.org> - 1.4.6-1
- Update to 1.4.6 (stable)

* Wed Sep 23 2015 Remi Collet <remi@fedoraproject.org> - 1.4.4-1
- Update to 1.4.4 (stable)

* Tue Sep 15 2015 Remi Collet <remi@fedoraproject.org> - 1.4.2-1
- Update to 1.4.2 (stable)

* Mon Sep 14 2015 Remi Collet <remi@fedoraproject.org> - 1.4.0-1
- initial package, version 1.4.0 (stable)
